
%global pkg_name bytestring-trie
%global pkgver %{pkg_name}-%{version}


Name:           ghc-%{pkg_name}
Version:        0.2.7.2
Release:    1%{?dist}
Summary:        An efficient finite map from bytestrings to values

License:        BSD-3-Clause
Url:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkgver}/%{pkgver}.tar.gz

BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-base-devel
BuildRequires:  ghc-binary-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-deepseq-devel
%if %{with ghc_prof}
BuildRequires:  ghc-base-prof
BuildRequires:  ghc-binary-prof
BuildRequires:  ghc-bytestring-prof
BuildRequires:  ghc-deepseq-prof
%endif

%description
An efficient finite map from bytestrings to values.

The implementation is based on big-endian patricia trees, like "Data.IntMap".
We first trie on the elements of "Data.ByteString" and then trie on the
big-endian bit representation of those elements. Patricia trees have efficient
algorithms for union and other merging operations, but they're also quick for
lookups and insertions.

If you are only interested in being able to associate strings to values, then
you may prefer the 'hashmap' package which is faster for those only needing a
map-like structure. This package is intended for those who need the extra
capabilities that a trie-like structure can offer (e.g., structure sharing to
reduce memory costs for highly redundant keys, taking the submap of all keys
with a given prefix, contextual mapping, extracting the minimum and maximum
keys, etc.).


%package devel
Summary:        Haskell %{pkg_name} library development files
Provides:       %{name}-static = %{version}-%{release}
Provides:       %{name}-static = %{version}-%{release}
%if %{defined ghc_version}
Requires:       ghc-compiler = %{ghc_version}
%endif
Requires:       %{name} = %{version}-%{release}

%description devel
This package provides the Haskell %{pkg_name} library development
files.


%if %{with haddock}
%package doc
Summary:        Haskell %{pkg_name} library documentation
BuildArch:      noarch
Requires:       ghc-filesystem

%description doc
This package provides the Haskell %{pkg_name} library documentation.
%endif


%if %{with ghc_prof}
%package prof
Summary:        Haskell %{pkg_name} profiling library
Requires:       %{name}-devel = %{version}-%{release}
Supplements:    (%{name}-devel and ghc-prof)

%description prof
This package provides the Haskell %{pkg_name} profiling library.
%endif


%prep
%setup -q -n %{pkgver}


%build
%ghc_lib_build


%install
%ghc_lib_install


%files -f %{name}.files
%license LICENSE


%files devel -f %{name}-devel.files
%doc AUTHORS CHANGELOG README.md


%if %{with haddock}
%files doc -f %{name}-doc.files
%license LICENSE
%endif


%if %{with ghc_prof}
%files prof -f %{name}-prof.files
%endif


%changelog
* Thu Aug 08 2024 OpenCloudOS Release Engineering <releng@opencloudos.tech> - 0.2.7.2-1
- initial build
